@@ -86,7 +86,7 @@
 #define KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNOTIFICATIONS_NO_DEPRECATED
-#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KNOTIFICATIONS_NO_DEPRECATED_WARNINGS
 #  define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -198,7 +198,7 @@
 #define KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNOTIFICATIONS_NO_DEPRECATED
-#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KNOTIFICATIONS_NO_DEPRECATED_WARNINGS
 #  define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0
@@ -208,7 +208,7 @@
 #  ifdef KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
